<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="cs">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Aplikační proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Číslo portu</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Volitelné</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Po nastavení jděte do kontextové nabídky spouštěče aplikace na panelu a v té zaškrtněte „Použít proxy“</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neplatná IP adresa</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Neplatný port</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Odpojit</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Připojuje se</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Odpojit</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Opravdu chcete toto nastavení smazat?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Drátové připojení %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Bezdrátové připojení %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE připojení %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nová VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Typ VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Export</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplikační proxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Osobní bezdrátový přípojný bod</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Podrobnosti sítě</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systémová proxy</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Drátová síť</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrátová síť</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim letadlo</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptér drátové sítě</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Přidat síťové připojení</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptér bezdrátové sítě</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Připojit se ke skryté síti</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Vytvořit PPPoE připojení</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Stav VPN</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Vytvořit VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Import VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL adresa, ze které získat nastavení</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP adresa</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Číslo portu</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Přípojný bod</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Vytvořit přípojný bod</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Rozhraní</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Pásmo</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Hlavní DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sítě</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Předpona</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rychlost</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim letadlo</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Povolením režimu letadlo se vypne bezdrátová síť, osobní hotspot a Bluetooth.</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Neplatná DNS adresa</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nespojeno</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC adresa zařízení</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Klonovaná MAC adresa</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Přizpůsobit velikost MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Název už existuje</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Připojit automaticky</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Přidat nastavení</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Vytvořit přípojný bod</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Kopírovat IP adresu</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neplatná IP adresa</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Neplatná maska sítě</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Je povolena jen jedna brána</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neplatná brána</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Kopírovat IP adresu</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neplatná IP adresa</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Je povolena jen jedna brána</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neplatná brána</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Předpona</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Příručka</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovat</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP adresa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Použito jen v odpovídajících prostředcích</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metoda</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Předpona</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neplatná IP adresa</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Neplatná maska sítě</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neplatná brána</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP adres</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metoda</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Příručka</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovat</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Podrobnosti sítě</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systémová proxy</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplikační proxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim letadlo</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Podrobnosti sítě</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Střet IP adres</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázáno</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Příručka</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Nastavit prostřednictvím Network Manager</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Osobní bezdrátový přípojný bod</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Služba</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odmítnout EAP ověření</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odmítnout PAP ověření</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odmítnout CHAP ověření</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odmítnout MSCHAP ověření</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odmítnout MSCHAPv2 ověření</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nekomprimovat data algoritmem BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Nekomprimovat data algoritmem Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nekomprimovat záhlaví TCP protokolu</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nekomprimovat pole protokolu</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nekomprimovat adresní/řídící data</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Poslat PPP echo pakety</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Použít MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stavový MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Vytvořit PPPoE připojení</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Systémová proxy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Příručka</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Volitelné</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Číslo portu</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Nastavení proxy neuplatňovat pro výše uvedené stroje a domény</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL adresa, ze které získat nastavení</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Zabezpečení</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunelované TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Chráněné EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Uložit heslo pro tohoto uživatele</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Uložit heslo pro všechny uživatele</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Vždy se dotázat</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázáno</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonymní</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Ověřeno</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Oba</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Verze 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Verze 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP ověření</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Totožnost</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Volby pro heslo</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Soukromý klíč</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certifikát cert. autority</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Uživatelský certifikát</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonymní identif.</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisioning</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Soubor PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Vnitřní ověření</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Verze PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Soukromé heslo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Neplatné heslo</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 osobní</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Zabezpečení</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Klíč</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Vyžadováno zabezpečení</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Neplatné heslo</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 osobní</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 podnikové</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Sdílený klíč</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Nešifrováno</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Zabezpečení</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Ověření</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Klíč</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN – pokročilé</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Upravit číslo portu brány</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port brány</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Přizpůsobit interval pro nové vyjednání</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Interval pro nové vyjednání</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Komprimovat data algoritmem LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Použít TCP spojení</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Použít TAP zařízení</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Přizpůsobit MTU tunelu</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Přizpůsobit velikost UDP fragmentu</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Velikost UDP fragmentu</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Omezit TCP MSS pro tunel</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Náhodně přidělit Vzdálené servery</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN – pokročilé</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (výchozí)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Zabezpečené (výchozí)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Slabé</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T když je k dispozici (výchozí)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T vždy</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázáno</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH skupina 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH skupina 2 (výchozí)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH skupina 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (výchozí)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH skupina 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Doména</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Výrobce</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Šifrování</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Režim překonávání NAT překladu</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH skupina</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Místní port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Vypnout zjišťování neaktivního protějšku</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Zapnout IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Název skupiny</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Identif. skupiny</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Předsdílený klíč</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmy 1. fáze</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmy 2. fáze</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neplatná brána</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certifikát cert. autority</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Umožnit Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD skript</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Uživatelský certifikát</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Soukromý klíč</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Pro heslovou frázi klíče použít FSID</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neplatná brána</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certifikáty (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certifikáty s heslem (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statický klíč</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Uloženo</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Dotázat se</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Není požadováno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Typ ověření</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certifikát cert. autority</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Uživatelský certifikát</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Soukromý klíč</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Volby pro heslo</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Soukromé heslo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Přizpůsobit směr klíče</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Směr klíče</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP adresa protějšku</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Místní IP adresa</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Vše dostupné (výchozí)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bitů (méně bezpečné)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bitů (bezpečnější)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odmítnout EAP ověření</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odmítnout PAP ověření</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odmítnout CHAP ověření</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odmítnout MSCHAP ověření</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odmítnout MSCHAPv2 ověření</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nekomprimovat data algoritmem BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Nekomprimovat data algoritmem Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nekomprimovat záhlaví TCP protokolu</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nekomprimovat pole protokolu</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nekomprimovat adresní/řídící data</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Poslat PPP echo pakety</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Použít MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Zabezpečení</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stavový MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Stav VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Vytvořit VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Import VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Chyba při zavedení</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Chyba souboru</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Není požadováno</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP adresa serveru</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Číslo portu</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>V případě neúspěchu zkoušet pořád dokola znovu</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Soubor s cert. autoritou</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignorovat varování ohledně certifikátu</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Použít TLS rozšíření pro názvy hostitele</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Zabezpečení VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Šifra</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Ověření HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neplatná brána</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Uloženo</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Dotázat se</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Není požadováno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Volby pro heslo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Doména NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP adresa serveru</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Číslo portu</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neplatná brána</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Soukromý klíč</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smart Card</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Předsdílený klíč</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certifikát cert. autority</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Typ ověření</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Uživatelský certifikát</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Požádat o vnitřní IP adresu</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Vynutit zapouzdření UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Použít kompresi IP protokolu</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Navrhovat použití uživatelsky určené šifry</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>TLS VPN ověření</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Shoda předmětu</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Typ certifikátu protějšku</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Soubor s klíčem</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Přizpůsobit směr klíče</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Směr klíče</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neplatná brána</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Uloženo</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Dotázat se</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Není požadováno</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Volby pro heslo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Název skupiny</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Heslo skupiny</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Použít hybridní ověření</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Soubor s cert. autoritou</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Nejprve připojte kabel datové sítě</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptér drátové sítě</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Přidat síťové připojení</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Vybrat nastavení</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptér bezdrátové sítě</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Ukončit přípojný bod</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Pokud se chcete připojit k bezdrátové síti, je třeba nejprve vypnout přípojný bod</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Připojit se ke skryté síti</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>Wi-Fi</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nespojeno</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC adresa zařízení</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Přizpůsobit velikost MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>